import { PopulatedTransaction } from '@ethersproject/contracts';
import { NonceManager } from '@ethersproject/experimental';
import { EthAddress, OrderParams, PositiveBigNumber, StarkMethodParams, Token, Transaction, TransferParams } from '@imtbl/imx-link-types';
import { Stark } from "../../contracts";
import * as TE from 'fp-ts/TaskEither';
import * as t from 'io-ts';
/**
 * Immutable X Controller
 */
export declare class ImmutableXController {
    private signer;
    private accountMappingKey;
    private accountMapping;
    private activeKeyPair;
    private store;
    constructor(signer: NonceManager, accountMappingKey?: string);
    getAddress(): Promise<EthAddress>;
    get starkPublicKey(): string | undefined;
    getStarkPublicKey(path?: string): Promise<string>;
    getExchangeContract(contractAddress: string): Stark;
    sign(payload: any): Promise<string>;
    signStark(payload: any): Promise<string>;
    signRegistration(): Promise<string>;
    /**
     * StarkWare JSON-RPC Spec
     */
    account(layer: string, application: string, index: string): Promise<string>;
    signUserRegistration({ etherKey, starkPublicKey, nonce, }: {
        etherKey: string;
        starkPublicKey: string;
        nonce: string;
    }): TE.TaskEither<Error, string>;
    signDeposit(starkPublicKey: string, vaultId: string, token: Token, quantity: string, nonce: string): Promise<string>;
    signWithdraw(starkPublicKey: string, vaultId: string, token: Token, quantity: PositiveBigNumber, nonce: string): TE.TaskEither<Error, string>;
    transfer(from: TransferParams, to: TransferParams, token: Token, quantity: PositiveBigNumber, nonce: string, expirationTimestamp: string): TE.TaskEither<Error, string>;
    createOrder(starkPublicKey: string, sell: OrderParams, buy: OrderParams, sell_id: string, buy_id: string, nonce: t.Int, expirationTimestamp: t.Int): TE.TaskEither<Error, string>;
    register({ contractAddress, etherKey, starkPublicKey, operatorSignature, }: StarkMethodParams.StarkRegisterParams): TE.TaskEither<Error, PopulatedTransaction>;
    depositF({ contractAddress, starkPublicKey, quantity, token, vaultId, }: StarkMethodParams.StarkDepositParams): TE.TaskEither<Error, PopulatedTransaction>;
    deposit(params: StarkMethodParams.StarkDepositParamsTS): Promise<Transaction>;
    depositCancel(contractAddress: string, starkPublicKey: string, token: Token, vaultId: string): Promise<Transaction>;
    depositReclaim(contractAddress: string, starkPublicKey: string, token: Token, vaultId: string): Promise<Transaction>;
    withdrawal(contractAddress: string, starkPublicKey: string, token: Token): TE.TaskEither<Error, PopulatedTransaction>;
    fullWithdrawal(contractAddress: string, starkPublicKey: string, vaultId: string): Promise<Transaction>;
    freeze(contractAddress: string, starkPublicKey: string, vaultId: string): Promise<Transaction>;
    escape(contractAddress: string, starkPublicKey: string, vaultId: string, token: Token, quantity: PositiveBigNumber): Promise<Transaction>;
    mintNFT(tokenAddress: string): TE.TaskEither<Error, Transaction>;
    approveNFT({ tokenAddress, contractAddress, tokenId, }: StarkMethodParams.StarkApproveNFTParams): TE.TaskEither<Error, Transaction>;
    private assertStarkPublicKey;
    private getActiveKeyPair;
    private setActiveKeyPair;
    private getKeyPairFromPath;
    private getAccountMapping;
}
export default ImmutableXController;
//# sourceMappingURL=index.d.ts.map