import ImmutableXWallet from "../../wallet";
import { Signer } from '@ethersproject/abstract-signer';
import { EthAddress, HexadecimalString, ImmutableMethodParams, ImmutableMethodResults, OrderParams, Token } from '@imtbl/imx-link-types';
import { AxiosRequestConfig } from 'axios';
import * as T from 'fp-ts/Task';
import * as TE from 'fp-ts/TaskEither';
export declare type ImmutableXClientParams = {
    publicApiUrl: string;
    signer?: Signer;
    gasLimit?: string;
    gasPrice?: string;
    starkContractAddress?: string;
};
/**
 * Immutable X REST API Client
 */
export declare class ImmutableXClient {
    private publicApiUrl;
    private wallet;
    private contractAddress;
    private _address;
    private _starkPublicKey;
    private agent;
    constructor(publicApiUrl: string, wallet: ImmutableXWallet, contractAddress: EthAddress, _address: EthAddress, _starkPublicKey: HexadecimalString);
    static buildF(params: ImmutableXClientParams): TE.TaskEither<Error, ImmutableXClient>;
    static build({ publicApiUrl, signer, starkContractAddress, gasLimit, gasPrice, }: ImmutableXClientParams): Promise<ImmutableXClient>;
    get address(): import("io-ts").Branded<string, import("@imtbl/imx-link-types").EthAddressBrand>;
    get starkPublicKey(): import("io-ts").Branded<string, import("@imtbl/imx-link-types").HexadecimalStringBrand>;
    buildOptions(): AxiosRequestConfig;
    private get;
    private post;
    registerImxF({ etherKey, starkPublicKey, }: ImmutableMethodParams.ImmutableRegisterParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableRegisterResult>;
    getUserF(params: ImmutableMethodParams.ImmutableGetUserParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetUserResult>;
    getUser(params: ImmutableMethodParams.ImmutableGetUserParamsTS): Promise<{
        accounts: import("io-ts").Branded<string, import("@imtbl/imx-link-types").HexadecimalStringBrand>[];
    }>;
    registerImx(params: ImmutableMethodParams.ImmutableRegisterParamsTS): Promise<{
        tx_hash: string;
    }>;
    isRegisteredF(params: ImmutableMethodParams.ImmutableGetUserParams): TE.TaskEither<Error, boolean>;
    isRegistered(params: ImmutableMethodParams.ImmutableGetUserParamsTS): Promise<boolean>;
    isRegisteredStarkF(starkPublicKey: string): T.Task<boolean>;
    isRegisteredStark(starkPublicKey: string): Promise<boolean>;
    registerF(params: ImmutableMethodParams.ImmutableRegisterParams): TE.TaskEither<Error, string>;
    register(params: ImmutableMethodParams.ImmutableRegisterParamsTS): Promise<string>;
    registerStarkF({ etherKey, starkPublicKey, operatorSignature, }: ImmutableMethodParams.ImmutableStarkRegisterParams): TE.TaskEither<Error, string>;
    registerStark(params: ImmutableMethodParams.ImmutableStarkRegisterParamsTS): Promise<string>;
    mintNFTF({ tokenAddress }: ImmutableMethodParams.ImmutableMintNFTParams): TE.TaskEither<Error, string>;
    mintNFT(params: ImmutableMethodParams.ImmutableMintNFTParamsTS): Promise<string>;
    approveNFTF(params: ImmutableMethodParams.ImmutableStarkApproveNFTParams): TE.TaskEither<Error, string>;
    approveNFT(params: ImmutableMethodParams.ImmutableStarkApproveNFTParamsTS): Promise<string>;
    depositF({ user, token, quantity, }: ImmutableMethodParams.ImmutableGetSignableDepositParams): TE.TaskEither<Error, string>;
    deposit(params: ImmutableMethodParams.ImmutableGetSignableDepositParamsTS): Promise<string>;
    depositCancel(starkPublicKey: string, token: Token, vaultId: string): Promise<any>;
    depositReclaim(starkPublicKey: string, token: Token, vaultId: string): Promise<any>;
    prepareWithdrawalF({ user, token, quantity, }: ImmutableMethodParams.ImmutablePrepareWithdrawalParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableWithdrawalResult>;
    prepareWithdrawal(params: ImmutableMethodParams.ImmutablePrepareWithdrawalParamsTS): Promise<ImmutableMethodResults.ImmutableWithdrawalResult>;
    completeWithdrawalF({ starkPublicKey, token, }: ImmutableMethodParams.ImmutableCompleteWithdrawalParams): TE.TaskEither<Error, string>;
    completeWithdrawal(params: ImmutableMethodParams.ImmutableCompleteWithdrawalParamsTS): Promise<string>;
    transferF({ sender, token, quantity, receiver, }: ImmutableMethodParams.ImmutableTransferParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableTransferResult>;
    transfer(params: ImmutableMethodParams.ImmutableTransferParamsTS): Promise<ImmutableMethodResults.ImmutableTransferResult>;
    mintF(params: ImmutableMethodParams.ImmutableOffchainMintParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableOffchainMintResult>;
    mint(params: ImmutableMethodParams.ImmutableOffchainMintParamsTS): Promise<ImmutableMethodResults.ImmutableOffchainMintResult>;
    createOrderRequestF({ user, tokenSell, tokenBuy, amountSell, amountBuy, }: ImmutableMethodParams.ImmutableGetSignableOrderParams): TE.TaskEither<Error, {
        signableOrderResult: ImmutableMethodResults.ImmutableGetSignableOrderResult;
        sellParams: OrderParams;
        buyParams: OrderParams;
        signature: string;
    }>;
    createOrderF({ user, tokenSell, tokenBuy, amountSell, amountBuy, }: ImmutableMethodParams.ImmutableGetSignableOrderParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableCreateOrderResult>;
    createOrder(params: ImmutableMethodParams.ImmutableGetSignableOrderParamsTS): Promise<ImmutableMethodResults.ImmutableCreateOrderResult>;
    cancelOrder(starkPublicKey: string, orderId: string): Promise<any>;
    createTradeF({ user, tokenSell, tokenBuy, amountSell, amountBuy, orderId, }: ImmutableMethodParams.ImmutableGetSignableTradeParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableCreateTradeResult>;
    createTrade(params: ImmutableMethodParams.ImmutableGetSignableTradeParamsTS): Promise<ImmutableMethodResults.ImmutableCreateTradeResult>;
    getBalancesF(params: ImmutableMethodParams.ImmutableGetBalancesParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetBalancesResult>;
    getBalances(params: ImmutableMethodParams.ImmutableGetBalancesParamsTS): Promise<ImmutableMethodResults.ImmutableGetBalancesResult>;
    getVaults(starkPublicKey: string): Promise<any>;
    getOrderF({ orderId, }: ImmutableMethodParams.ImmutableGetOrderParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetOrderResult>;
    getOrder(params: ImmutableMethodParams.ImmutableGetOrderParamsTS): Promise<ImmutableMethodResults.ImmutableGetOrderResult>;
    getOrdersF(query?: ImmutableMethodParams.ImmutableGetOrdersParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetOrdersResult>;
    getOrders(params?: ImmutableMethodParams.ImmutableGetOrdersParamsTS): Promise<ImmutableMethodResults.ImmutableGetOrdersResult>;
    getAssetsF(query: ImmutableMethodParams.ImmutableGetAssetsParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetAssetsResult>;
    getAssets(params: ImmutableMethodParams.ImmutableGetAssetsParamsTS): Promise<ImmutableMethodResults.ImmutableGetAssetsResult>;
    getAssetF({ address, id, }: ImmutableMethodParams.ImmutableGetAssetParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableAsset>;
    getAsset(params: ImmutableMethodParams.ImmutableGetAssetParamsTS): Promise<ImmutableMethodResults.ImmutableAsset>;
    getApplicationsF(query?: ImmutableMethodParams.ImmutableGetApplicationsParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetApplicationsResult>;
    getApplications(params?: ImmutableMethodParams.ImmutableGetApplicationsParamsTS): Promise<ImmutableMethodResults.ImmutableGetApplicationsResult>;
    getTradeF({ id, }: ImmutableMethodParams.ImmutableGetTradeParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableTrade>;
    getTrade(params: ImmutableMethodParams.ImmutableGetTradeParamsTS): Promise<ImmutableMethodResults.ImmutableTrade>;
    getCollectionsF(query: ImmutableMethodParams.ImmutableGetCollectionsParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetCollectionsResult>;
    getCollections(params: ImmutableMethodParams.ImmutableGetCollectionsParamsTS): Promise<ImmutableMethodResults.ImmutableGetCollectionsResult>;
    getCollectionF({ address, }: ImmutableMethodParams.ImmutableGetCollectionParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableCollection>;
    getCollection(params: ImmutableMethodParams.ImmutableGetCollectionParamsTS): Promise<ImmutableMethodResults.ImmutableCollection>;
    getDepositsF(query?: ImmutableMethodParams.ImmutableGetDepositsParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetDepositsResult>;
    getDeposits(params?: ImmutableMethodParams.ImmutableGetDepositsParamsTS): Promise<ImmutableMethodResults.ImmutableGetDepositsResult>;
    getDepositF({ id, }: ImmutableMethodParams.ImmutableGetDepositParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableDeposit>;
    getDeposit(params: ImmutableMethodParams.ImmutableGetDepositParamsTS): Promise<ImmutableMethodResults.ImmutableDeposit>;
    getTransferF({ id, }: ImmutableMethodParams.ImmutableGetTransferParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableTransfer>;
    getTransfer(params: ImmutableMethodParams.ImmutableGetTransferParamsTS): Promise<ImmutableMethodResults.ImmutableTransfer>;
    getWithdrawalF({ id, }: ImmutableMethodParams.ImmutableGetWithdrawalParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableWithdrawal>;
    getWithdrawal(params: ImmutableMethodParams.ImmutableGetWithdrawalParamsTS): Promise<ImmutableMethodResults.ImmutableWithdrawal>;
    getWithdrawalsF(query?: ImmutableMethodParams.ImmutableGetWithdrawalsParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetWithdrawalsResult>;
    getWithdrawals(params?: ImmutableMethodParams.ImmutableGetWithdrawalsParamsTS): Promise<ImmutableMethodResults.ImmutableGetWithdrawalsResult>;
    getTransfersF(query?: ImmutableMethodParams.ImmutableGetTransfersParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetTransfersResult>;
    getTransfers(params?: ImmutableMethodParams.ImmutableGetTransfersParamsTS): Promise<ImmutableMethodResults.ImmutableGetTransfersResult>;
    getTradesF(query?: ImmutableMethodParams.ImmutableGetTradesParams): TE.TaskEither<Error, ImmutableMethodResults.ImmutableGetTradesResult>;
    getPaginatedResults<P, T>(params: P, fn: (params: P) => TE.TaskEither<Error, {
        cursor: string;
        result: T[];
    }>): TE.TaskEither<Error, T[]>;
    getTrades(params?: ImmutableMethodParams.ImmutableGetTradesParamsTS): Promise<ImmutableMethodResults.ImmutableGetTradesResult>;
    getLastAvailableNonce(starkPublicKey: string): Promise<{
        Nonce: string;
    }>;
    getTokenBody(token: Token): any;
    private decodeForFunction;
}
export default ImmutableXClient;
//# sourceMappingURL=index.d.ts.map